Module ethers_core::abi [−][src]
This module implements extensions to the ethabi API.
Modules
| param_type | Function and event param types. |
| token | ABI param and parsing for it. |
Structs
| Abi | API building calls to contracts ABI. |
| Constructor | Contract constructor specification. |
| Contract | API building calls to contracts ABI. |
| Event | Contract event. |
| EventParam | Event param specification. |
| Events | Contract events iterator. |
| Function | Contract function specification. |
| Functions | Contract functions iterator. |
| InvalidOutputType | |
| Log | Decoded log. |
| LogParam | Decoded log param. |
| Param | Function param. |
| RawLog | Ethereum log. |
| RawTopicFilter | Raw topic filter. |
| TopicFilter | Topic filter. |
| TupleParam | Tuple params specification |
Enums
| Error | Ethabi errors |
| ParamType | Function and event param types. |
| ParseError | |
| StateMutability | Whether a function modifies or reads blockchain state |
| Token | Ethereum ABI params. |
| Topic | Acceptable topic possibilities. |
Traits
| Detokenize | Output type possible to deserialize from Contract ABI |
| EventExt | Extension trait for |
| FunctionExt | Extension trait for |
| FunctionOutputDecoder | Contract functions generated by ethabi-derive |
| LogFilter | Common filtering functions that are available for any event. |
| ParseLog | trait common to things (events) that have an associated |
| Tokenizable | Simplified output type for single value. |
| TokenizableItem | Marker trait for |
| Tokenize | Tokens conversion trait |
Functions
| decode | Decodes ABI compliant vector of bytes into vector of tokens described by types param. |
| encode | Encodes vector of tokens into ABI compliant vector of bytes. |
| parse_abi | Parses a “human readable abi” string vector |
Type Definitions
| Address | ABI address. |
| Bytes | ABI bytes. |
| FixedBytes | ABI fixed bytes. |
| Hash | Commonly used FixedBytes of size 32 |
| Int | ABI signed integer. |
| Result | Ethabi result type |
| Uint | ABI unsigned integer. |
| Word | ABI word. |